# HermesPy
HermesPy (Heterogeneous Radio Mobile Simulator - Python) is a semi-static link-level simulator based on time-driven mechanisms.

It provides a framework for the link-level simulation of a multi-RAT wireless link, consisting of
multiple transmit and receive modems, which may operate at different carrier frequencies. 
In addition to simulating individual transmission links, HermesPy allows the analysis of both co-channel and
adjacent-channel interference among different communication systems.

## Features

The current release version 0.2.7 serves as a platform for joint development.
Its main focus is to provide a software architecture that can be easily extended.
Detailed core features as well as a release plan can be found in the
[features](https://barkhausen-institut.github.io/hermespy/features.html) list.

## Documentation

For detailed [installation instructions](https://barkhausen-institut.github.io/hermespy/installation.html),
tutorials and a full API documentation, please consult the official
[documentation](https://barkhausen-institut.github.io/hermespy/index.html) website.

## Contributors

* [Andre Noll Barreto](https://gitlab.com/anollba)
* [Tobias Kronauer](https://github.com/tokr-bit)
* [Jan Adler](https://github.com/adlerjan)

## Copyright
Copyright (C) 2021 Barkhausen Institut gGmbH
